@@ -2,7 +2,7 @@ import numpy as np
 from typing import List
 import re
 import matplotlib.pyplot as plt
-from variables import *
+from variable_lib_drturtle.variables import *
 
 
 U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
